==> haskell-summoner-2.0.1.1-678.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-summoner.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 summoner
version:              2.0.1.1
visibility:           public
id:                   summoner-2.0.1.1-Dp9PTEx9qZa9yfqRhtOY6B
key:                  summoner-2.0.1.1-Dp9PTEx9qZa9yfqRhtOY6B
license:              MPL-2.0
copyright:            2018-2020 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Veronika Romashkina, Dmitrii Kovanikov
stability:            stable
homepage:             https://github.com/kowainik/summoner
synopsis:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects.

description:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects.
    See [README.md](https://github.com/kowainik/summoner#-summoner) for details.

category:             CLI, CLI Tool, Development
abi:                  85697266c38a44ce7320c15aeb43a829
exposed:              True
exposed-modules:
    Summoner Summoner.CLI Summoner.Config Summoner.CustomPrelude
    Summoner.Decision Summoner.Default Summoner.GhcVer Summoner.License
    Summoner.Mode Summoner.Project Summoner.Question Summoner.Settings
    Summoner.Source Summoner.Template Summoner.Template.Cabal
    Summoner.Template.Doc Summoner.Template.GitHub
    Summoner.Template.Haskell Summoner.Template.Script
    Summoner.Template.Stack Summoner.Text Summoner.Tree

hidden-modules:       Paths_summoner
import-dirs:          /usr/lib/ghc-9.6.6/site-local/summoner-2.0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/summoner-2.0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/summoner-2.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-summoner
hs-libraries:         HSsummoner-2.0.1.1-Dp9PTEx9qZa9yfqRhtOY6B
depends:
    base-4.18.2.1 relude-1.2.2.2-KgVg8kiFcZ1L2qmKYg26m0
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi
    colourista-0.1.0.2-IcvjUpc9Rbw706VyAKHsEE containers-0.6.7
    directory-1.3.8.5 filepath-1.4.300.1
    generic-data-1.1.0.2-HLcGPIZzjH0IAjUpoZUMFS
    gitrev-1.3.1-HjgHeGOzFY1JvYhlt8eDSs
    neat-interpolation-0.5.1.4-LgltL8bGunlFCtvssaeg3T
    optparse-applicative-0.18.1.0-AbA9pm273O8LTotNJ1t1CE
    process-1.6.19.0 shellmet-0.0.5.0-LX10n1Zi5evJZ1HpFqeuzN text-2.0.2
    time-1.12.2 tomland-1.3.3.3-7CCFuuPpg026Qt9Z2AIKrv
    validation-selective-0.2.0.0-KILlRG2ti48J3BGw7UAm1V

haddock-interfaces:   /usr/share/doc/haskell-summoner/html/summoner.haddock
haddock-html:         /usr/share/doc/haskell-summoner/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-summoner-2.0.1.1-679-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-summoner.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 summoner
version:              2.0.1.1
visibility:           public
id:                   summoner-2.0.1.1-1fuWLtcMOqD2WXN8TaVq3o
key:                  summoner-2.0.1.1-1fuWLtcMOqD2WXN8TaVq3o
license:              MPL-2.0
copyright:            2018-2020 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Veronika Romashkina, Dmitrii Kovanikov
stability:            stable
homepage:             https://github.com/kowainik/summoner
synopsis:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects.

description:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects.
    See [README.md](https://github.com/kowainik/summoner#-summoner) for details.

category:             CLI, CLI Tool, Development
abi:                  c27bd25b2683c065b03afd568a7bf051
exposed:              True
exposed-modules:
    Summoner Summoner.CLI Summoner.Config Summoner.CustomPrelude
    Summoner.Decision Summoner.Default Summoner.GhcVer Summoner.License
    Summoner.Mode Summoner.Project Summoner.Question Summoner.Settings
    Summoner.Source Summoner.Template Summoner.Template.Cabal
    Summoner.Template.Doc Summoner.Template.GitHub
    Summoner.Template.Haskell Summoner.Template.Script
    Summoner.Template.Stack Summoner.Text Summoner.Tree

hidden-modules:       Paths_summoner
import-dirs:          /usr/lib/ghc-9.6.6/site-local/summoner-2.0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/summoner-2.0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/summoner-2.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-summoner
hs-libraries:         HSsummoner-2.0.1.1-1fuWLtcMOqD2WXN8TaVq3o
depends:
    base-4.18.2.1 relude-1.2.2.2-9PkKwzJM4Ma4UBkBxLnTrv
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y
    colourista-0.1.0.2-HTbTpLqd7UA3ymn8nCJJVI containers-0.6.7
    directory-1.3.8.5 filepath-1.4.300.1
    generic-data-1.1.0.2-D5ZHZSdEvCZ90jghyWktw7
    gitrev-1.3.1-HjgHeGOzFY1JvYhlt8eDSs
    neat-interpolation-0.5.1.4-4VDX25yQx4CGEE32HBtT8D
    optparse-applicative-0.18.1.0-BnGHnrTdK6d4c7MmJxSY0G
    process-1.6.19.0 shellmet-0.0.5.0-5wFljDtiwo8MIHgU4BEvA text-2.0.2
    time-1.12.2 tomland-1.3.3.3-7X8YK7Tf2KJ6KJXaMSZQvR
    validation-selective-0.2.0.0-3ecfd9K5DIA1eGBn8v2bT

haddock-interfaces:   /usr/share/doc/haskell-summoner/html/summoner.haddock
haddock-html:         /usr/share/doc/haskell-summoner/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
